@@ -4,15 +4,8 @@
 import logging
 import sys
 
-try:
-    import pkg_resources
-    __version__ = pkg_resources.get_distribution('tldextract').version  # pylint: disable=no-member
-except ImportError:
-    __version__ = '(local)'
-except pkg_resources.DistributionNotFound:
-    __version__ = '(local)'
-
 from .tldextract import TLDExtract
+from ._version import version as __version__
 
 try:
     unicode
@@ -30,7 +23,7 @@ def main():
         prog='tldextract',
         description='Parse hostname from a url or fqdn')
 
-    parser.add_argument('--version', action='version', version='%(prog)s ' + __version__)  # pylint: disable=no-member
+    parser.add_argument('--version', action='version', version='%(prog)s ' + __version__)
     parser.add_argument('input', metavar='fqdn|url',
                         type=unicode, nargs='*', help='fqdn or url')
 
