@@ -58,6 +58,7 @@ import logging
 import os
 import pkgutil
 import re
+import threading
 
 import idna
 
@@ -193,6 +194,7 @@ class TLDExtract(object):
         self.suffix_list_urls = tuple(url.strip() for url in suffix_list_urls if url.strip())
 
         self.cache_file = os.path.expanduser(cache_file or '')
+        self.cache_file_lock = threading.Lock()
         self.fallback_to_snapshot = fallback_to_snapshot
         if not (self.suffix_list_urls or self.cache_file or self.fallback_to_snapshot):
             raise ValueError("The arguments you have provided disable all ways for tldextract "
@@ -264,8 +266,8 @@ class TLDExtract(object):
 
         if self._extractor:
             return self._extractor
-
-        tlds = self._get_cached_tlds()
+        with self.cache_file_lock:
+            tlds = self._get_cached_tlds()
         if tlds:
             tlds.extend(self.extra_suffixes)
             self._extractor = _PublicSuffixListTLDExtractor(tlds)
@@ -289,7 +291,8 @@ class TLDExtract(object):
             raise Exception("tlds is empty, but fallback_to_snapshot is set"
                             " to false. Cannot proceed without tlds.")
 
-        self._cache_tlds(tlds)
+        with self.cache_file_lock:
+            self._cache_tlds(tlds)
 
         tlds.extend(self.extra_suffixes)
         self._extractor = _PublicSuffixListTLDExtractor(tlds)
@@ -342,7 +345,16 @@ class TLDExtract(object):
                 with open(self.cache_file, 'w') as cache_file:
                     json.dump(tlds, cache_file)
             except IOError as ioe:
-                LOG.warning("unable to cache TLDs in file %s: %s", self.cache_file, ioe)
+                LOG.warning(
+                    (
+                        "unable to cache TLDs in file %s. This will refresh the "
+                        "Public Suffix List over HTTP every app startup. "
+                        "Construct your `TLDExtract` with a writable `cache_file` or "
+                        "set `cache_file=False` to silence this warning. %s"
+                    ),
+                    self.cache_file,
+                    ioe,
+                )
 
 
 TLD_EXTRACTOR = TLDExtract()
@@ -403,6 +415,6 @@ def _decode_punycode(label):
     if looks_like_puny:
         try:
             return idna.decode(label.encode('ascii')).lower()
-        except UnicodeError:
+        except (UnicodeError, IndexError):
             pass
     return lowered
